@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2017-07-02'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -189,8 +189,10 @@ sub _request {
         $resp = $ua->request($req);
         if ($resp->code =~ /^[5]/ && $args{retries} >= ++$tries) {
             log_warn("Got error %s (%s) from server when POST-ing to %s%s, retrying (%d/%d) ...",
-                     $url, $args{note} ? " ($args{note})" : "",
-                     $resp->code, $resp->message, $tries, $args{retries});
+                     $resp->code, $resp->{message},
+                     $url,
+                     $args{note} ? " ($args{note})" : "",
+                     $tries, $args{retries});
             sleep $args{retry_delay};
             next;
         }
@@ -861,7 +863,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.41 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-06-28.
+This document describes version 0.42 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-07-02.
 
 =head1 SYNOPSIS
 
